@@ -2,6 +2,7 @@
 
 import sys
 import requests
+
 from .helpers.formatting import to_json
 
 def useQueryAsOn(query: str, variables, token: str, gql_endpoint: str):
@@ -14,9 +15,10 @@ def useQueryAsOn(query: str, variables, token: str, gql_endpoint: str):
 
     response = r.json()
 
-    if 'errors' in response:
-        for error in response['errors']:
-            print(error, file=sys.stderr)
+    # # Debugging
+    # if 'errors' in response:
+    #     for error in response['errors']:
+    #         print(error, file=sys.stderr)
 
     return response
 
